<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Optimax_Core;

use radiustheme\Optimax\Helper;
extract($data);

$prefix      = Constants::$theme_prefix;
$thumb_size  = "{$prefix}-size2";

if ( get_query_var('paged') ) {
  $paged = get_query_var('paged');
}
else if ( get_query_var('page') ) {
  $paged = get_query_var('page');
}
else {
  $paged = 1;
}

$args = [
  'posts_per_page'   => $posts_per_page,
  'suppress_filters' => false,
  'ignore_sticky_posts' => 1,
  'orderby'          => $orderby,
  'paged'            => $paged,
];

switch ( $orderby ) {
  case 'title':
  case 'menu_order':
  $args['order'] = 'ASC';
  break;
}

$bool = is_array($multiple_category);
$bool = $bool && count( $multiple_category ) ;
if ($bool) {
  $args['category__in'] = $multiple_category;
}
$query = new \WP_Query( $args );
$temp = Helper::wp_set_temp_query( $query );

if ( $posts_per_page % 2 == 1 ) {
	$is_offset = 'offset-lg-3 offset-md-3 offset-xl-0 ';
}

$col_class = "col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col}";

$masonary_grid = 'no';
$masonry_grid_class = "";
$masonry_grid_item_class = "";
if ($masonary_grid == 'yes') {
  $masonry_grid_class = "masonry-grid";
  $masonry_grid_item_class = "masonry-grid-item";
}

$i = 1;
?>

<div class="rtel-blog-post-1">
  <div class="row <?php echo esc_attr( $masonry_grid_class ); ?>">
    <?php while( $query->have_posts() ){ $query->the_post(); ?>
      <?php 
      $post = get_post();
      $img                = Helper::generate_thumbnail_image( $post, $thumb_size, true );
      $permalink          = get_the_permalink($post);
      $content            = Helper::generate_excerpt($post, $no_of_excerpt_words);
      $author             = get_the_author_meta( 'display_name' , $post->post_author );
      $author_post_link   = get_author_posts_url($post->post_author);
      $categories         = get_the_category( $post->ID );
      $avatar             = get_avatar_url($post->post_author);
      $having_image_class = $img ? 'has-image' : 'no-image';
      ?>
      <div class="<?php if ( ( $i == $posts_per_page ) && ( $posts_per_page % 2 == 1 ) ) { echo esc_attr( $is_offset ) ; } echo esc_attr( $col_class ); ?> <?php echo esc_attr( $masonry_grid_item_class ); ?>">
        <div class="blog-box-layout1">
          <div class="hover-border"></div>
          <?php if ( has_post_thumbnail() ) { ?>
            <div class="rtin-img">
              <a href="<?php echo esc_url( $permalink ); ?>"><?php the_post_thumbnail( $thumb_size ); ?></a>
            </div>
          <?php } else { ?>
				<a href="<?php echo esc_url( $permalink ); ?>"><img src="<?php echo esc_url( Helper::get_img( 'noimage/noimage_490x330.jpg' ) ); ?>" alt="<?php echo esc_attr( $post->post_title ); ?>"></a>				
		  <?php } ?>
          <div class="rtin-content">
            <div class="rtin-author <?php echo esc_attr( $having_image_class ); ?>">
              <?php if ($avatar): ?>
                <div class="author-img">
                  <img src="<?php echo esc_attr( $avatar ); ?>" alt="<?php esc_html_e( 'Author avatar', 'optimax-core' );?>">
                </div>
              <?php endif ?>
              <span><?php echo esc_html( $author ); ?></span>
            </div>
            <?php if ( $show_date == 'yes' || $show_category == 'yes'): ?>
              <ul class="entry-meta <?php echo esc_attr( $having_image_class ); ?>">
                <?php if ( $show_date == 'yes' ): ?>
                  <li><i class="far fa-clock"></i>
                    <?php $unixtimestamp =  get_the_time('U', $post );
                    echo date_i18n( get_option( 'date_format' ), $unixtimestamp );?></li>
                <?php endif ?>
                <?php if ( $show_category == 'yes' ): ?>
                  <li><i class="fas fa-folder-open"></i>
                    <?php foreach ($categories as $category): ?>
                      <?php
                      $category_link = get_category_link( $category );
                      ?>
                      <a href="<?php echo esc_url( $category_link ); ?>">
                        <?php echo esc_html( $category->cat_name ); ?>
                      </a>
                    <?php endforeach ?>
                  </li>
                <?php endif ?>
              </ul>
            <?php endif ?>

            <h3 class="post-title"><a href="<?php echo esc_html( $permalink ); ?>"><?php echo esc_html( $post->post_title ); ?></a></h3>
            <p><?php echo wp_kses_post( $content ); ?><?php echo esc_html( $postfix_text ); ?></p>
              <?php if ( $show_readmore == 'yes' ): ?>
                <div class="action-area adjust_padding">
                  <a href="<?php echo esc_url( $permalink ); ?>" class="rtin-btn">
                    <?php echo esc_html( $read_more_text ); ?>
                    <i class="fas fa-long-arrow-alt-right"></i>
                  </a>
                </div>
              <?php endif ?>
          </div>
        </div>
      </div>
    <?php $i++; } ?>
  </div>
  <?php if ( $pagination_display == 'yes' ): ?>
    <div class="pagination-layout1">
      <?php get_template_part( 'template-parts/pagination' ) ?>
    </div>
  <?php endif ?>
  <?php Helper::wp_reset_temp_query( $temp ); ?>
</div>

