<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Optimax_Core;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use radiustheme\Optimax\Helper;

if ( ! defined( 'ABSPATH' ) ) exit;

class Service_Gallery extends Custom_Widget_Base {
  public function __construct( $data = [], $args = null ){
    $this->rt_name = esc_html__( 'Service Gallery', 'optimax-core' );
    $this->rt_base = 'rt-service-gallery';
    $this->rt_translate = [
      'cols'  => [
        '12' => esc_html__( '1 Col', 'optimax-core' ),
        '6'  => esc_html__( '2 Col', 'optimax-core' ),
        '4'  => esc_html__( '3 Col', 'optimax-core' ),
        '3'  => esc_html__( '4 Col', 'optimax-core' ),
        '2'  => esc_html__( '6 Col', 'optimax-core' ),
      ],
    ];
    parent::__construct( $data, $args );
  }

  private function rt_cat_dropdown() {
    $prefix = Constants::$theme_prefix;

    $terms = get_terms( [
      'taxonomy' => "{$prefix}_service_category",
      'hide_empty' => true,
    ]);

    $category_dropdown = [];
    foreach ( $terms as $category ) {
      $category_dropdown[$category->term_id] = $category->name;
    }

    return $category_dropdown;
  }
  public function rt_fields(){
    $fields = [
      [
        'mode'    => 'section_start',
        'id'      => 'sec_general',
        'label'   => esc_html__( 'General', 'optimax-core' ),
      ],
      [
        'type'    => Controls_Manager::SELECT2,
        'id'      => 'style',
        'label'   => esc_html__( 'Layout Style', 'optimax-core' ),
        'options' => [
          'style1' => esc_html__( 'style 1', 'optimax-core' ),
          'style2' => esc_html__( 'style 2', 'optimax-core' ),
          'style3' => esc_html__( 'style 3', 'optimax-core' ),
          'style4' => esc_html__( 'style 4', 'optimax-core' ),
          'style5' => esc_html__( 'style 5', 'optimax-core' ),
          'style6' => esc_html__( 'style 6', 'optimax-core' ),
        ],
        'default' => 'style1',
      ],
      [
        'type'        => Controls_Manager::SWITCHER,
        'id'          => 'pagination_display',
        'label_on' => esc_html__( 'Show', 'optimax-core' ),
        'label_off' => esc_html__( 'Hide', 'optimax-core' ),
        'label'       => esc_html__( 'Show Pagination', 'optimax-core' ),
        'default'     => "no",
      ],	  
      [
        'type'        => Controls_Manager::SELECT2,
        'id'          => 'multiple_category',
        'label'       => __( 'Categories', 'optimax-core' ),
        'options'     => $this->rt_cat_dropdown(),
        'multiple'    => true,
        'description' => esc_html__( 'All categories is selected by default', 'optimax-core' ),
      ],
      [
        'type'        => Controls_Manager::NUMBER,
        'id'          => 'posts_per_page',
        'label'       => esc_html__( 'Posts Per Page', 'optimax-core' ),
        'default'     => 3,
      ],	  
      [
        'type'        => Controls_Manager::SWITCHER,
        'id'          => 'show_iconimage',
        'image' 	  => esc_html__( 'Show Image', 'optimax-core' ),
        'icon' 		  => esc_html__( 'Show Icon', 'optimax-core' ),
        'label'       => esc_html__( 'Show Image/Icon', 'optimax-core' ),
        'default'     => 'image',
      ],
      [
        'type'    => Controls_Manager::SELECT2,
        'id'      => 'orderby',
        'label'   => esc_html__( 'Order By', 'optimax-core' ),
        'options' => [
          'date'        => esc_html__( 'Date (Recents comes first)', 'optimax-core' ),
          'title'       => esc_html__( 'Title', 'optimax-core' ),
          'menu_order'  => esc_html__( 'Custom Order (Available via Order field inside Page Attributes box)', 'optimax-core' ),
        ],
        'default' => 'date',
      ],
      [
        'type'        => Controls_Manager::NUMBER,
        'id'          => 'no_of_excerpt_words',
        'label'       => esc_html__( 'Number Of words for excerpt', 'optimax-core' ),
        'default'     => 25,
      ],
      [
        'type'        => Controls_Manager::TEXT,
        'id'          => 'read_more_text',
        'label'       => esc_html__( 'Read More Text', 'optimax-core' ),
        'default'     => 'Read More',
        'condition' => [ 'style' => [ 'style1', 'style2', 'style3', 'style5', 'style6' ] ],
      ],
      [
        'type'        => Controls_Manager::SWITCHER,
        'id'          => 'enable_link',
        'label_on' => esc_html__( 'Yes', 'optimax-core' ),
        'label_off' => esc_html__( 'NO', 'optimax-core' ),
        'label'       => esc_html__( 'Enable Link', 'optimax-core' ),
        'default'     => 'yes',
        'condition' => ['style' => ['style-none']],
      ],
      [
        'mode' => 'section_end',
      ],
      
      // Responsive Columns for general
      // it will generate bootstrap column
      [
        'mode'    => 'section_start',
        'id'      => 'sec_responsive',
        'label'   => esc_html__( 'Number of Responsive Columns', 'optimax-core' ),
      ],
      [
        'type'    => Controls_Manager::SELECT2,
        'id'      => 'col_xl',
        'label'   => esc_html__( 'Desktops: > 1199px', 'optimax-core' ),
        'options' => $this->rt_translate['cols'],
        'default' => '4',
      ],
      [
        'type'    => Controls_Manager::SELECT2,
        'id'      => 'col_lg',
        'label'   => esc_html__( 'Desktops: > 991px', 'optimax-core' ),
        'options' => $this->rt_translate['cols'],
        'default' => '4',
      ],
      [
        'type'    => Controls_Manager::SELECT2,
        'id'      => 'col_md',
        'label'   => esc_html__( 'Tablets: > 767px', 'optimax-core' ),
        'options' => $this->rt_translate['cols'],
        'default' => '6',
      ],
      [
        'type'    => Controls_Manager::SELECT2,
        'id'      => 'col_sm',
        'label'   => esc_html__( 'Phones: > 576px', 'optimax-core' ),
        'options' => $this->rt_translate['cols'],
        'default' => '12',
      ],
      [
        'type'    => Controls_Manager::SELECT2,
        'id'      => 'col',
        'label'   => esc_html__( 'Phones: < 576px', 'optimax-core' ),
        'options' => $this->rt_translate['cols'],
        'default' => '12',
      ],
      [
        'mode' => 'section_end',
      ],

         // Starting Style Section 
      [
        'mode'    => 'section_start',
        'id'      => 'title_style_section',
        'label'   => esc_html__( 'Title Style', 'optimax-core' ),
        'tab'     => Controls_Manager::TAB_STYLE,
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'title_color',
        'label'     => esc_html__( 'Title Color', 'optimax-core' ),
        'selectors' => [
          '{{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content .rtin-title a' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content .rtin-title a' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content .rtin-title a' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content .item-title a' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery4 .rtin-service-box .rtin-content .rtin-title a' => 'color: {{VALUE}}',
         
        ],
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'title_hover_color',
        'label'     => esc_html__( 'Title Hover Color', 'optimax-core' ),
        // selector hover is bit tricky
        'selectors' => [
          '{{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content .rtin-title a:hover' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content .rtin-title a:hover' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content .rtin-title a:hover' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content .item-title a:hover' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery4 .rtin-service-box .rtin-content .rtin-title a:hover' => 'color: {{VALUE}}',
          
        ],
      ],
      [
        'mode'           => 'group',
        'type'           => Group_Control_Typography::get_type(),
        'name'           => 'title_typo',
        'label'          => esc_html__( 'Title Typography', 'optimax-core' ),
        // Its Not An ARRAY
        // Its Not An ARRAY
        'selector'       => '
          {{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content .rtin-title,
          {{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content .rtin-title,
          {{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content .rtin-title,
          {{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content .item-title,
          {{WRAPPER}} .rtel-service-gallery4 .rtin-service-box .rtin-content .rtin-title
          
        ',
      ],
      [
        'type'       => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%', 'em' ],
        'id'         => 'title_margin',
        'label'      => __( 'Title Margin', 'optimax-core' ),                 
        'selectors'  => [
          '{{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content .rtin-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
          '{{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content .rtin-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
          '{{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content .rtin-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
          '{{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content .item-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
          '{{WRAPPER}} .rtel-service-gallery4 .rtin-service-box .rtin-content .rtin-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
       
        ],
        'separator'  => 'before',
      ],
      [
        'mode' => 'section_end',
      ],
      [
        'mode'      => 'section_start',
        'id'        => 'content_style_section',
        'label'     => esc_html__( 'Content Style', 'optimax-core' ),
        'tab'       => Controls_Manager::TAB_STYLE,
        'condition' => [ 'style' => [ 'style1', 'style2','style5', 'style3', 'style3'] ],
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'content_color',
        'label'     => esc_html__( 'Content Color', 'optimax-core' ),
        'selectors' => [
          '{{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content p' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content p' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content p' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content p' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content p' => 'color: {{VALUE}}',
        ],
      ],
      [
        'mode'           => 'group',
        'type'           => Group_Control_Typography::get_type(),
        'name'           => 'content_typo',
        'label'          => esc_html__( 'Content Typography', 'optimax-core' ),
        // Not Array
        // Not Array
        'selector'       => '
          {{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content p,
          {{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content p,
          {{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content p,
          {{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content p
        ',
      ],
      [
        'type'       => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%', 'em' ],
        'id'         => 'content_margin',
        'label'      => __( 'Content Margin', 'optimax-core' ),                 
        'selectors'  => [
          '{{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
          '{{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
          '{{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
          '{{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
        ],
        'separator'  => 'before',
      ],
      [
        'mode'            => 'group',
        'condition'   => [ 'style' => 'style5' ],
        'separator'       => 'before',
        'label_block'     => true,
        'type'            => Group_Control_Background::get_type(),
        'name'            => 'content_background',
        'id'              => 'content_background',
        'types'           => [ 'classic', 'gradient', ],
        'fields_options'  => [
          'background' => [
            'label' => esc_html__( ' Background', 'optimax-core' ),
          ],
        ],
        'selector'        => '
          {{WRAPPER}} .rtel-service-gallery5 .rtin-service-box,
          {{WRAPPER}} noselector
        ',
      ],
      [
        'mode' => 'section_end',
      ],
       // read more color and typo
      [
        'mode'      => 'section_start',
        'id'        => 'readmore_style',
        'label'     => esc_html__( 'Readmore', 'optimax-core' ),
        'tab'       => Controls_Manager::TAB_STYLE,
        'condition' => [ 'style' => [ 'style1', 'style2', 'style3', 'style5', ] ],
      ],
      [
        'mode'           => 'group',
        'type'           => Group_Control_Typography::get_type(),
        'name'           => 'readmore_typo',
        'label'          => esc_html__( 'Readmore Typography', 'optimax-core' ),
        'selector'       => '
          {{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content a.readmore,
          {{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content a.readmore,
          {{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content a.readmore,
          {{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content a.readmore
        ',
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'readmore_color',
        'label'     => esc_html__( 'Readmore Color', 'optimax-core' ),
        'selectors' => [
          '{{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content a.readmore' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content a.readmore' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content a.readmore' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content a.readmore' => 'color: {{VALUE}}',
        ],
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'readmore_color_hover',
        'label'     => esc_html__( 'Readmore Hover Color', 'optimax-core' ),
        'selectors' => [
          '{{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content a.readmore:hover' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content a.readmore:hover' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content a.readmore:hover' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content a.readmore:hover' => 'color: {{VALUE}}',
        ],
      ],

      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'readmore_icon_color',
        'label'     => esc_html__( 'Readmore Icon Color', 'optimax-core' ),
        'selectors' => [
          '{{WRAPPER}}  .rtel-service-gallery1 .rtin-service-box .rtin-content a.readmore i' => 'color: {{VALUE}}',
          '{{WRAPPER}}  .rtel-service-gallery2 .rtin-service-box .rtin-content a.readmore i' => 'color: {{VALUE}}',
          '{{WRAPPER}}  .rtel-service-gallery5 .rtin-service-box .rtin-content a.readmore i' => 'color: {{VALUE}}',
          '{{WRAPPER}}  .rtel-service-gallery3 .rtin-service-box .item-content a.readmore i' => 'color: {{VALUE}}',
        ],
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'readmore_icon_hover_color',
        'label'     => esc_html__( 'Readmore Icon Hover Color', 'optimax-core' ),
        'selectors' => [
          '{{WRAPPER}} .rtel-service-gallery1 .rtin-service-box .rtin-content a.readmore:hover i' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content a.readmore:hover i' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content a.readmore:hover i' => 'color: {{VALUE}}',
          '{{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-content a.readmore:hover i' => 'color: {{VALUE}}',
        ],
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'readmore_border_color',
        'label'     => esc_html__( 'Readmore Border Color', 'optimax-core' ),
        'condition' => [ 'style' => [ 'style2', 'style3', ] ],
        'selectors' => [
          '{{WRAPPER}}  .rtel-service-gallery2 .rtin-service-box .rtin-content a.readmore' => 'border-color: {{VALUE}}',
          '{{WRAPPER}}  .rtel-service-gallery5 .rtin-service-box .rtin-content a.readmore' => 'border-color: {{VALUE}}',
          '{{WRAPPER}}  .rtel-service-gallery3 .rtin-service-box .item-content a.readmore' => 'border-color: {{VALUE}}',
        ],
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'readmore_hover_border_color',
        'label'     => esc_html__( 'Readmore Hover Border Color', 'optimax-core' ),
        'condition' => [ 'style' => [ 'style2', 'style3', ] ],
        'selectors' => [
          '{{WRAPPER}}  .rtel-service-gallery2 .rtin-service-box .rtin-content a.readmore:hover' => 'border-color: {{VALUE}}',
          '{{WRAPPER}}  .rtel-service-gallery5 .rtin-service-box .rtin-content a.readmore:hover' => 'border-color: {{VALUE}}',
          '{{WRAPPER}}  .rtel-service-gallery3 .rtin-service-box .item-content a.readmore:hover' => 'border-color: {{VALUE}}',
        ],
      ],
      [
        'mode'            => 'group',
        'separator'       => 'before',
        'label_block'     => true,
        'type'            => Group_Control_Background::get_type(),
        'name'            => 'readmore_hover_background',
        'types'           => [ 'gradient' ],
        'label'           => esc_html__( 'Button Hover Background', 'optimax-core' ),
        'condition'       => [ 'style' => [ 'style2', 'style3', 'style5', ] ],
        'fields_options'  => [
          'background' => [
            'label' => esc_html__( 'Hover Background', 'optimax-core' ),
          ],
        ],
        'selector'        => '
          {{WRAPPER}} .rtel-service-gallery2 .rtin-service-box .rtin-content a.readmore:hover,
          {{WRAPPER}} .rtel-service-gallery5 .rtin-service-box .rtin-content a.readmore:hover,
          {{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .rtin-content a.readmore:hover
        ',
      ],
     
      
      
      [
        'mode' => 'section_end',
      ],

      // Other Style  
      [
        'mode'      => 'section_start',
        'id'        => 'other_style_section',
        'label'     => esc_html__( 'Others Style', 'optimax-core' ),
        'tab'       => Controls_Manager::TAB_STYLE,
        'condition' => [ 'style' => [ 'style4', ] ],
      ],
      [
        'mode'           => 'group',
        'type'           => Group_Control_Typography::get_type(),
        'name'           => 'meta_text_typo',
        'label'          => esc_html__( 'Meta Typography', 'optimax-core' ),
        'selector'       => '
          
          {{WRAPPER}} .rtel-service-gallery4 .rtin-service-box .rtin-content .rtin-subtitle

        ',
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'meta_link_color',
        'label'     => esc_html__( 'Meta Link Color', 'optimax-core' ),
        'selectors' => [
          '{{WRAPPER}} .rtel-service-gallery4 .rtin-service-box .rtin-content .rtin-subtitle a' => 'color: {{VALUE}}',
        ],
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'meta_link_hover_color',
        'label'     => esc_html__( 'Meta Link Hover Color', 'optimax-core' ),
        'selectors' => [
          '{{WRAPPER}} .rtel-service-gallery4 .rtin-service-box .rtin-content .rtin-subtitle a:hover' => 'color: {{VALUE}}',
        ],
      ],
      [
        'mode' => 'section_end',
      ],

      // svg icon color for style 3

      [
        'mode'    => 'section_start',
        'id'      => 'svg_icon_color',
        'label'   => esc_html__( 'Service Icon Style', 'optimax-core' ),
        'tab'     => Controls_Manager::TAB_STYLE,
        'condition' => [ 'style' => [ 'style3'] ],
      ],
      [
        'type'    => Controls_Manager::COLOR,
        'id'      => 'icon_background_fill_color',
        'label'   => esc_html__( 'Icon Background fill color', 'optimax-core' ),
      ],
      [
        'type'    => Controls_Manager::COLOR,
        'id'      => 'service_icon_color',
        'label'   => esc_html__( 'Icon Color', 'optimax-core' ),
        'selectors' => [ '{{WRAPPER}} .rtel-service-gallery3 .rtin-service-box .item-icon i' => 'color: {{VALUE}}' ],
      ],
      [
        'mode' => 'section_end',
      ],



      // isotope navigation 
      [
        'mode'      => 'section_start',
        'id'        => 'isotope_section_style',
        'label'     => esc_html__( 'Isotope Navigation Style', 'optimax-core' ),
        'tab'       => Controls_Manager::TAB_STYLE,
        'condition' => [ 'style' => [ 'style4', ] ],
      ],
      [
        'mode'           => 'group',
        'type'           => Group_Control_Typography::get_type(),
        'name'           => 'isotope_navigation_typo',
        'label'          => esc_html__( 'Navigation Title Typography', 'optimax-core' ),
        'selector'       => '{{WRAPPER}} .isotop-btn .nav-item',
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'isotope_navigation_color',
        'label'     => esc_html__( 'Isotope Navigation Color', 'optimax-core' ),
        'selectors' => [
          '{{WRAPPER}} .isotop-btn .nav-item' => 'color: {{VALUE}}',
          '{{WRAPPER}} .isotop-btn .nav-item:before' => 'color: {{VALUE}}',
        ],
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'isotope_navigation_hover_color',
        'label'     => esc_html__( 'Isotope Navigation Hover Color', 'optimax-core' ),
        'selectors' => [
          '{{WRAPPER}}  .isotop-btn .nav-item.current' => 'color: {{VALUE}}',
          '{{WRAPPER}}  .isotop-btn .nav-item:hover'   => 'color: {{VALUE}}',
        ],
      ],
      [
        'type'      => Controls_Manager::COLOR,
        'id'        => 'isotope_navigation_border_color',
        'label'     => esc_html__( 'Isotope Title Border color', 'optimax-core' ),
        'selectors' => [ '{{WRAPPER}} .isotop-btn .nav-item:after' => 'background-color: {{VALUE}}' ],
      ],

      
      [
        'mode' => 'section_end',
      ],

    ];
    return $fields;
  }

  private function rt_load_scripts() {
    wp_enqueue_style( 'isotope-pkgd' );
    wp_enqueue_script( 'imagesloaded' );
  }
  protected function render() {
    $data = $this->get_settings();
    $this->rt_load_scripts();
    switch ( $data['style'] ) {
      case 'style6':
      $template = 'view-6';
      break;
      case 'style2':
      $template = 'view-2';
      break;
      case 'style3':
      $template = 'view-3';
      break;
      case 'style4':
      $template = 'view-4';
      break;
      case 'style5':
      $template = 'view-5';
      break;
      default:
      $template = 'view-1';
      break;
    }
    return $this->rt_template( $template, $data );
  }
}
