<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Optimax_Core;

use \FW_Ext_Backups_Demo;
use \WPCF7_ContactFormTemplate;

if ( ! defined( 'ABSPATH' ) ) exit;
class Demo_Importer {
  public function __construct() {
    add_filter( 'plugin_action_links_rt-demo-importer/rt-demo-importer.php', [$this, 'add_action_links']); // Link from plugins page
    add_filter( 'rt_demo_installer_warning', [$this, 'data_loss_warning']);
    add_filter( 'fw:ext:backups-demo:demos', [$this, 'demo_config']);
    add_action( 'fw:ext:backups:tasks:success:id:demo-content-install', [$this, 'after_demo_install']);

    // following line of code can be uncomment by end user if his/her server memory is not sufficient -
    // for big task like demo import and image resize at same time.
    // following line disable auto image resize after demo import 
    // use `Regenerate Thumbnails` after demo import 
    
    //add_filter( 'fw:ext:backups:add-restore-task:image-sizes-restore', '__return_false' ); // Enable it to skip image restore step
  }

  public function add_action_links( $links ) {
    $mylinks = [
      '<a href="' . esc_url( admin_url( 'tools.php?page=fw-backups-demo-content' ) ) . '">'.__( 'Install Demo Contents', 'optimax-core' ).'</a>',
    ];
    return array_merge( $links, $mylinks );
  }

  public function data_loss_warning( $links ) {
    $html  = '<div style="margin-top:20px;color:#f00;font-size:20px;line-height:1.3;font-weight:600;margin-bottom:40px;border-color: #f00;border-style: dashed;border-width: 1px 0;padding:10px 0;">';
    $html .= esc_html__( 'Warning: All your old data will be lost if you install One Click demo data from here, so it is suitable only for a new website.', 'optimax-core');
    $html .= '</div>';
    return $html;
  }

  public function demo_config( $demos ) {
    $demos_array = [
      'demo1' => [
        'title' => esc_html__( 'Home 1', 'optimax-core' ),
        'screenshot' => plugins_url( 'demo-screenshots/screenshot1.jpg', __FILE__ ),
        'preview_link' => 'https://radiustheme.com/demo/wordpress/themes/optimax/',
      ],
      'demo2' => [
        'title' => esc_html__( 'Home 2', 'optimax-core' ),
        'screenshot' => plugins_url( 'demo-screenshots/screenshot2.jpg', __FILE__ ),
        'preview_link' => 'https://radiustheme.com/demo/wordpress/themes/optimax/home-2/',
      ],
      'demo3' => [
        'title' => esc_html__( 'Home 3', 'optimax-core' ),
        'screenshot' => plugins_url( 'demo-screenshots/screenshot3.jpg', __FILE__ ),
        'preview_link' => 'https://radiustheme.com/demo/wordpress/themes/optimax/home-3/',
      ],
      'demo4' => [
        'title' => esc_html__( 'Home 4', 'optimax-core' ),
        'screenshot' => plugins_url( 'demo-screenshots/screenshot4.jpg', __FILE__ ),
        'preview_link' => 'https://radiustheme.com/demo/wordpress/themes/optimax/home-4/',
      ],	  
      'demo5' => [
        'title' => esc_html__( 'Home 1 ( One Page )', 'optimax-core' ),
        'screenshot' => plugins_url( 'demo-screenshots/screenshot1.jpg', __FILE__ ),
        'preview_link' => 'https://radiustheme.com/demo/wordpress/themes/optimax/home-1-one-page/',
      ],
      'demo6' => [
        'title' => esc_html__( 'Home 2 ( One Page )', 'optimax-core' ),
        'screenshot' => plugins_url( 'demo-screenshots/screenshot2.jpg', __FILE__ ),
        'preview_link' => 'https://radiustheme.com/demo/wordpress/themes/optimax/home-2-one-page/',
      ],
      'demo7' => [
        'title' => esc_html__( 'Home 3 ( One Page )', 'optimax-core' ),
        'screenshot' => plugins_url( 'demo-screenshots/screenshot3.jpg', __FILE__ ),
        'preview_link' => 'https://radiustheme.com/demo/wordpress/themes/optimax/home-3-one-page/',
      ],
      'demo8' => [
        'title' => esc_html__( 'Home 4 ( One Page )', 'optimax-core' ),
        'screenshot' => plugins_url( 'demo-screenshots/screenshot4.jpg', __FILE__ ),
        'preview_link' => 'https://radiustheme.com/demo/wordpress/themes/optimax/home-4-one-page/',
      ],

    ];
    $download_url = 'http://demo.radiustheme.com/wordpress/demo-content/optimax/';
    foreach ($demos_array as $id => $data) {
      $demo = new FW_Ext_Backups_Demo($id, 'piecemeal', [
        'url' => $download_url,
        'file_id' => $id,
      ]);
      $demo->set_title($data['title']);
      $demo->set_screenshot($data['screenshot']);
      $demo->set_preview_link($data['preview_link']);

      $demos[ $demo->get_id() ] = $demo;

      unset($demo);
    }

    return $demos;
  }

  public function after_demo_install( $collection ){
    // Update front page id
    $demos = [
      'demo1'  => 1947,
      'demo2'  => 5290,
      'demo3'  => 5372,
      'demo4'  => 9624,	  
      'demo5'  => 9560,
      'demo6'  => 9564,
      'demo7'  => 9578,
      'demo8'  => 9703,
    ];

    $data = $collection->to_array();

    foreach( $data['tasks'] as $task ) {
      if( $task['id'] == 'demo:demo-download' ){
        $demo_id = $task['args']['demo_id'];
        $page_id = $demos[$demo_id];
        update_option( 'page_on_front', $page_id );
        flush_rewrite_rules();
        break;
      }
    }

    // Update contact form 7 email
	
	$cf7ids = array( 3192, 1976, 8501, 3539, 1978, 8224, 2845, 5352, 5131, 8262, 9626 );
    foreach ( $cf7ids as $cf7id ) {
      $mail = get_post_meta( $cf7id, '_mail', true );
      $mail['recipient'] = get_option('admin_email');
            if ( empty( $mail ) ) {
               $mail = [];
            }

      if ( class_exists( 'WPCF7_ContactFormTemplate' ) ) {
        $pattern = "/<[^@\s]*@[^@\s]*\.[^@\s]*>/"; // <email@email.com>
        $replacement = '<'. WPCF7_ContactFormTemplate::from_email().'>';
        $mail['sender'] = preg_replace($pattern, $replacement, $mail['sender']);
      }

      update_post_meta( $cf7id, '_mail', $mail );
    }
	
	// Update Commerce emails
	$admin_email = get_option( 'admin_email' );
  }
}

new Demo_Importer;
